==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/es.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Cargando previsualización...",
    "Saved" : "Guardado",
    "Admin" : "Administración",
    "a safe home for all your data" : "un hogar seguro para todos tus datos",
    "Name cannot be empty" : "El nombre no puede estar vacío",
    "The given name is too long" : "El nombre provisto es demasiado largo",
    "The given web address is too long" : "La dirección provista es demasiado larga",
    "The given legal notice address is too long" : "El aviso legal dado es demasiado largo",
    "The given privacy policy address is too long" : "La dirección de la política de privacidad dada es demasiado larga",
    "The given slogan is too long" : "El eslogan provisto es demasiado largo",
    "The given color is invalid" : "El color provisto es inválido",
    "The file was uploaded" : "Se ha subido el archivo",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo para subir excede la directiva upload_max_filesize en php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo para subir excede la directiva MAX_FILE_SIZE que se especificó en el formulario HTML",
    "The file was only partially uploaded" : "El archivo se ha subido solo parcialmente",
    "No file was uploaded" : "No se ha subido ningún archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No se puede escribir el archivo en el disco",
    "A PHP extension stopped the file upload" : "Una extensión PHP ha cancelado la subida de archivos",
    "No file uploaded" : "No se ha subido archivo",
    "Unsupported image type" : "Tipo de imagen no soportado",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ya estás usando un tema personalizado. La configuración de la aplicación de temas puede ser sobrescrita por el.",
    "Theming" : "Tema",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidad",
    "Adjust the Nextcloud theme" : "Ajusta el tema de Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Los temas hacen posible personalizar fácilmente la apariencia de tu instancia y los clientes soportados. Esto será visible para todos los usuarios.",
    "Name" : "Nombre",
    "Reset to default" : "Vovler a configuración por defecto",
    "Web link" : "Enlace web",
    "Slogan" : "Eslogan",
    "Color" : "Color",
    "Logo" : "Logo",
    "Upload new logo" : "Subir nuevo logo",
    "Login image" : "Imagen de fondo para inicio de sesión",
    "Upload new login background" : "Subir una nueva imagen de fondo para inicio de sesión",
    "Remove background image" : "Eliminar imagen de fondo",
    "Advanced options" : "Opciones avanzadas",
    "Legal notice link" : "Enlace al aviso legal",
    "Privacy policy link" : "Enlace a la política de privacidad",
    "Header logo" : "Logo de la cabecera",
    "Upload new header logo" : "Subir nuevo logo de la cabecera",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Subir nuevo favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instala la extensión de PHP Imagemagick con soporte para imágenes SVG para generar automáticamente faviconos basados en el logo y color subidos.",
    "You are already using a custom theme" : "Ya estás usando un tema personalizado",
    "reset to default" : "restaurar a configuración inicial",
    "Web address" : "Dirección web",
    "Web address https://…" : "Dirección web https://",
    "There is no error, the file uploaded with success" : "No ha habido errores, el archivo ha subido satisfactoriamente",
    "The uploaded file was only partially uploaded" : "El archivo para subir ha sido solo parcialmente subido",
    "Failed to write file to disk." : "Fallo al escribir el archivo al disco.",
    "A PHP extension stopped the file upload." : "Una extensión de PHP ha detenido la subida del archivo."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/es.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Cargando previsualización...",
    "Saved" : "Guardado",
    "Admin" : "Administración",
    "a safe home for all your data" : "un hogar seguro para todos tus datos",
    "Name cannot be empty" : "El nombre no puede estar vacío",
    "The given name is too long" : "El nombre provisto es demasiado largo",
    "The given web address is too long" : "La dirección provista es demasiado larga",
    "The given legal notice address is too long" : "El aviso legal dado es demasiado largo",
    "The given privacy policy address is too long" : "La dirección de la política de privacidad dada es demasiado larga",
    "The given slogan is too long" : "El eslogan provisto es demasiado largo",
    "The given color is invalid" : "El color provisto es inválido",
    "The file was uploaded" : "Se ha subido el archivo",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo para subir excede la directiva upload_max_filesize en php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo para subir excede la directiva MAX_FILE_SIZE que se especificó en el formulario HTML",
    "The file was only partially uploaded" : "El archivo se ha subido solo parcialmente",
    "No file was uploaded" : "No se ha subido ningún archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No se puede escribir el archivo en el disco",
    "A PHP extension stopped the file upload" : "Una extensión PHP ha cancelado la subida de archivos",
    "No file uploaded" : "No se ha subido archivo",
    "Unsupported image type" : "Tipo de imagen no soportado",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ya estás usando un tema personalizado. La configuración de la aplicación de temas puede ser sobrescrita por el.",
    "Theming" : "Tema",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidad",
    "Adjust the Nextcloud theme" : "Ajusta el tema de Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Los temas hacen posible personalizar fácilmente la apariencia de tu instancia y los clientes soportados. Esto será visible para todos los usuarios.",
    "Name" : "Nombre",
    "Reset to default" : "Vovler a configuración por defecto",
    "Web link" : "Enlace web",
    "https://…" : "https://…",
    "Slogan" : "Eslogan",
    "Color" : "Color",
    "Logo" : "Logo",
    "Upload new logo" : "Subir nuevo logo",
    "Login image" : "Imagen de fondo para inicio de sesión",
    "Upload new login background" : "Subir una nueva imagen de fondo para inicio de sesión",
    "Remove background image" : "Eliminar imagen de fondo",
    "Advanced options" : "Opciones avanzadas",
    "Legal notice link" : "Enlace al aviso legal",
    "Privacy policy link" : "Enlace a la política de privacidad",
    "Header logo" : "Logo de la cabecera",
    "Upload new header logo" : "Subir nuevo logo de la cabecera",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Subir nuevo favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instala la extensión de PHP Imagemagick con soporte para imágenes SVG para generar automáticamente faviconos basados en el logo y color subidos."
},
"nplurals=2; plural=(n != 1);");
